@@ -10,12 +10,12 @@ from functools import wraps
 
 def parse_limit(method):
     """Wrapper to parse 'limit' kwarg in base.BaseAPI.search
-    and base.BaseAPI.search_detailed methods."""
+    and base.BaseAPI.search_detail methods."""
 
     @wraps(method)
     def wrapper(*args, **kwargs):
         limit = kwargs.get("limit")
-        # if limit is valid
+        # Yield method if limit is valid
         if limit is None or isinstance(limit, int) and limit >= 0:
             yield from method(*args, **kwargs)
 
